@@ -39,7 +39,8 @@ from .urls_patterns import URL_ADMIN_SERVER_INFO, URL_ADMIN_CLIENT_AUTHZ_RESOURC
     URL_ADMIN_GROUP_MEMBERS, URL_ADMIN_USER_STORAGE, URL_ADMIN_GROUP_PERMISSIONS, URL_ADMIN_IDPS, URL_ADMIN_USER_REALM_ROLES, \
     URL_ADMIN_USER_CLIENT_ROLES_AVAILABLE, URL_ADMIN_USERS, URL_ADMIN_CLIENT_AUTHZ_RESOURCES_ID, URL_ADMIN_CLIENT_AUTHZ_POLICIES, \
     URL_ADMIN_CLIENT_AUTHZ_POLICIES_ID, URL_ADMIN_CLIENT_AUTHZ_PERMISSIONS, URL_ADMIN_CLIENT_AUTHZ_PERMISSIONS_ID, \
-    URL_ADMIN_USER_CLIENT_ROLES_COMPOSITE_ID, URL_ADMIN_GROUP_CLIENT_ROLES, USE_ADMIN_CLIENT_AUTHZ_POLICIES_EVAL 
+    URL_ADMIN_USER_CLIENT_ROLES_COMPOSITE_ID, URL_ADMIN_GROUP_CLIENT_ROLES, USE_ADMIN_CLIENT_AUTHZ_POLICIES_EVAL, \
+    URL_ADMIN_DEFAULT_GROUPS
 
 def serialize(obj):
     """JSON serializer for objects not serializable by default json code"""
@@ -381,6 +382,35 @@ class KeycloakAdmin:
         data_raw = self.connection.raw_get(URL_ADMIN_SERVER_INFO)
         return raise_error_from_response(data_raw, KeycloakGetError)
 
+    def update_default_groups(self, group_id):
+        """
+        Update the default groups.
+
+        :param group_id: id of group
+        :param payload: GroupRepresentation
+        http://www.keycloak.org/docs-api/3.3/rest-api/#_grouprepresentation
+
+        :return: Keycloak server response
+        """
+        params_path = {"realm-name": self.realm_name, "id": group_id}
+        payload = {"groupId": group_id}
+        data_raw = self.connection.raw_put(URL_ADMIN_DEFAULT_GROUPS.format(**params_path), data=json.dumps(payload))
+        return raise_error_from_response(data_raw, KeycloakGetError, expected_code=204)
+
+    def delete_default_groups(self, group_id):
+        """
+        Delete the default groups.
+
+        :param group_id: id of group
+        :param payload: GroupRepresentation
+        http://www.keycloak.org/docs-api/3.3/rest-api/#_grouprepresentation
+
+        :return: Keycloak server response
+        """
+        params_path = {"realm-name": self.realm_name, "id": group_id}
+        data_raw = self.connection.raw_delete(URL_ADMIN_DEFAULT_GROUPS.format(**params_path))
+        return raise_error_from_response(data_raw, KeycloakGetError, expected_code=204)
+
     def get_mapped_group_id(self, groupname, reference_db_id):
         """
         Get internal keycloak group id from groupname
